==> vmngclient-0.18.1.dev0.tar.gz: vmngclient-0.18.1.dev0/vmngclient/endpoints/configuration/policy/list/port.py <==
# mypy: disable-error-code="empty-body"
from vmngclient.endpoints import APIEndpoints, delete, get, post, put
from vmngclient.model.policy.lists import PortList
from vmngclient.model.policy.policy_list import (
    InfoTag,
    PolicyListEndpoints,
    PolicyListId,
    PolicyListInfo,
    PolicyListPreview,
)
from vmngclient.typed_list import DataSequence


class PortListEditPayload(PortList, PolicyListId):
    pass


class PortListInfo(PortList, PolicyListInfo):
    pass


class ConfigurationPolicyPortList(APIEndpoints, PolicyListEndpoints):
    @post("/template/policy/list/port")
    def create_policy_list(self, payload: PortList) -> PolicyListId:
        ...

    @delete("/template/policy/list/port/{id}")
    def delete_policy_list(self, id: str) -> None:
        ...

    @delete("/template/policy/list/port")
    def delete_policy_lists_with_info_tag(self, params: InfoTag) -> None:
        ...

    @put("/template/policy/list/port/{id}")
    def edit_policy_list(self, id: str, payload: PortListEditPayload) -> None:
        ...

    @get("/template/policy/list/port/{id}")
    def get_lists_by_id(self, id: str) -> PortListInfo:
        ...

    @get("/template/policy/list/port", "data")
    def get_policy_lists(self) -> DataSequence[PortListInfo]:
        ...

    @get("/template/policy/list/port/filtered", "data")
    def get_policy_lists_with_info_tag(self, params: InfoTag) -> DataSequence[PortListInfo]:
        ...

    @post("/template/policy/list/port/preview")
    def preview_policy_list(self, payload: PortList) -> PolicyListPreview:
        ...

    @get("/template/policy/list/port/preview/{id}")
    def preview_policy_list_by_id(self, id: str) -> PolicyListPreview:
        ...

==> vmngclient-0.22.1.tar.gz: vmngclient-0.22.1/vmngclient/endpoints/configuration/policy/list/port.py <==
# mypy: disable-error-code="empty-body"
from uuid import UUID

from vmngclient.endpoints import APIEndpoints, delete, get, post, put
from vmngclient.models.policy.lists import PortList
from vmngclient.models.policy.policy_list import (
    InfoTag,
    PolicyListEndpoints,
    PolicyListId,
    PolicyListInfo,
    PolicyListPreview,
)
from vmngclient.typed_list import DataSequence


class PortListEditPayload(PortList, PolicyListId):
    pass


class PortListInfo(PortList, PolicyListInfo):
    pass


class ConfigurationPolicyPortList(APIEndpoints, PolicyListEndpoints):
    @post("/template/policy/list/port")
    def create_policy_list(self, payload: PortList) -> PolicyListId:
        ...

    @delete("/template/policy/list/port/{id}")
    def delete_policy_list(self, id: UUID) -> None:
        ...

    @delete("/template/policy/list/port")
    def delete_policy_lists_with_info_tag(self, params: InfoTag) -> None:
        ...

    @put("/template/policy/list/port/{id}")
    def edit_policy_list(self, id: UUID, payload: PortListEditPayload) -> None:
        ...

    @get("/template/policy/list/port/{id}")
    def get_lists_by_id(self, id: UUID) -> PortListInfo:
        ...

    @get("/template/policy/list/port", "data")
    def get_policy_lists(self) -> DataSequence[PortListInfo]:
        ...

    @get("/template/policy/list/port/filtered", "data")
    def get_policy_lists_with_info_tag(self, params: InfoTag) -> DataSequence[PortListInfo]:
        ...

    @post("/template/policy/list/port/preview")
    def preview_policy_list(self, payload: PortList) -> PolicyListPreview:
        ...

    @get("/template/policy/list/port/preview/{id}")
    def preview_policy_list_by_id(self, id: UUID) -> PolicyListPreview:
        ...
